Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.FamilieGruppe Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.FamilieGruppe einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.FamilieGruppe) | Gemeinde_Modelle.FamilieGruppe |
__str__(self) (Definiert in Gemeinde_Modelle.FamilieGruppe) | Gemeinde_Modelle.FamilieGruppe |
R_familie (Definiert in Gemeinde_Modelle.FamilieGruppe) | Gemeinde_Modelle.FamilieGruppe | static
R_gruppe (Definiert in Gemeinde_Modelle.FamilieGruppe) | Gemeinde_Modelle.FamilieGruppe | static